@@ -1,5 +1,5 @@
 package QuadPres;
-$QuadPres::VERSION = '0.28.0';
+$QuadPres::VERSION = '0.28.1';
 use strict;
 use warnings;
 
@@ -867,7 +867,7 @@ QuadPres
 
 =head1 VERSION
 
-version 0.28.0
+version 0.28.1
 
 =head1 NAME
 
@@ -875,7 +875,7 @@ QuadPres - a presentation / slides manager.
 
 =head1 VERSION
 
-version 0.28.0
+version 0.28.1
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
@@ -985,7 +985,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/quadpres/issues>
+L<https://github.com/shlomif/quad-pres/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
